==> angular-bootstrap-lightbox-0.12.1.tgz: angular-bootstrap-lightbox/README.md <==
# Installation
> `npm install --save @types/angular-bootstrap-lightbox`

# Summary
This package contains type definitions for angular-bootstrap-lightbox (https://github.com/compact/angular-bootstrap-lightbox).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/angular-bootstrap-lightbox.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/angular-bootstrap-lightbox/index.d.ts)
````ts
// Type definitions for angular-bootstrap-lightbox 0.12
// Project: https://github.com/compact/angular-bootstrap-lightbox
// Definitions by: Roland Zwaga <https://github.com/rolandzwaga>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

declare namespace angular.bootstrap.lightbox {

    export interface ILightboxImageInfo {
        url: string;
        width: number;
        height: number;
        thumbUrl?: string | undefined;
        caption?: string | undefined;
    }

    export interface IImageDimensionLimits  {
        minWidth?: number | undefined;
        minHeight?: number | undefined;
        maxWidth?: number | undefined;
        maxHeight?: number | undefined;
    }

    export interface IImageDimensionParameter {
        windowWidth:number;
        windowHeight:number;
        imageWidth:number;
        imageHeight:number;
    }

    export interface IModalDimensionsParameter {
        windowWidth:number;
        windowHeight:number;
        imageDisplayWidth:number;
        imageDisplayHeight:number;
    }

    export interface IModalDimensions {
        width:number;
        height:number;
    }

    export interface ILightbox {
        openModal(
            images:ILightboxImageInfo[],
            index:number,
            modalParams?: { [key: string]: any }, // angular.ui.bootstrap.IModalSettings
        ):void;
    }

    export interface ILightBoxProvider {
        templateUrl:string;
        calculateImageDimensionLimits:(dimensions:IImageDimensionParameter)=>IImageDimensionLimits;
        calculateModalDimensions:(dimensions:IModalDimensionsParameter)=>IModalDimensions;
    }
}

````

### Additional Details
 * Last updated: Wed, 07 Jul 2021 21:44:16 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Roland Zwaga](https://github.com/rolandzwaga).

==> angular-bootstrap-lightbox-0.12.2.tgz: angular-bootstrap-lightbox/README.md <==
# Installation
> `npm install --save @types/angular-bootstrap-lightbox`

# Summary
This package contains type definitions for angular-bootstrap-lightbox (https://github.com/compact/angular-bootstrap-lightbox).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/angular-bootstrap-lightbox.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/angular-bootstrap-lightbox/index.d.ts)
````ts
// Type definitions for angular-bootstrap-lightbox 0.12
// Project: https://github.com/compact/angular-bootstrap-lightbox
// Definitions by: Roland Zwaga <https://github.com/rolandzwaga>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

declare namespace angular.bootstrap.lightbox {
    export interface ILightboxImageInfo {
        url: string;
        width: number;
        height: number;
        thumbUrl?: string | undefined;
        caption?: string | undefined;
    }

    export interface IImageDimensionLimits {
        minWidth?: number | undefined;
        minHeight?: number | undefined;
        maxWidth?: number | undefined;
        maxHeight?: number | undefined;
    }

    export interface IImageDimensionParameter {
        windowWidth: number;
        windowHeight: number;
        imageWidth: number;
        imageHeight: number;
    }

    export interface IModalDimensionsParameter {
        windowWidth: number;
        windowHeight: number;
        imageDisplayWidth: number;
        imageDisplayHeight: number;
    }

    export interface IModalDimensions {
        width: number;
        height: number;
    }

    export interface ILightbox {
        openModal(
            images: ILightboxImageInfo[],
            index: number,
            modalParams?: { [key: string]: any }, // angular.ui.bootstrap.IModalSettings
        ): void;
    }

    export interface ILightBoxProvider {
        templateUrl: string;
        calculateImageDimensionLimits: (dimensions: IImageDimensionParameter) => IImageDimensionLimits;
        calculateModalDimensions: (dimensions: IModalDimensionsParameter) => IModalDimensions;
    }
}

````

### Additional Details
 * Last updated: Fri, 22 Sep 2023 18:11:03 GMT
 * Dependencies: none
 * Global values: none

# Credits
These definitions were written by [Roland Zwaga](https://github.com/rolandzwaga).
